@@ -2,10 +2,17 @@
 from PyObjCTools.TestSupport import *
 from LaunchServices import *
 
-class TestLSSharedFileList (TestCase):
-    def testIncomplete(self):
-        self.fail("Add header tests for <LaunchServices/LSSharedFileList.h>")
+try:
+    long
+except NameError:
+    long = int
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+class TestLSSharedFileList (TestCase):
     def testTypes(self):
         self.assertIsCFType(LSSharedFileListRef)
         self.assertIsCFType(LSSharedFileListItemRef)
@@ -23,9 +30,12 @@ class TestLSSharedFileList (TestCase):
         self.assertIsInstance(kLSSharedFileListVolumesComputerVisible, unicode)
         self.assertIsInstance(kLSSharedFileListVolumesIDiskVisible, unicode)
         self.assertIsInstance(kLSSharedFileListVolumesNetworkVisible, unicode)
+        self.assertIsInstance(kLSSharedFileListItemHidden, unicode)
+
+    @min_os_level('10.5')
+    def testMagicConstants10_5(self):
         self.assertIsInstance(kLSSharedFileListItemBeforeFirst, LSSharedFileListItemRef)
         self.assertIsInstance(kLSSharedFileListItemLast, LSSharedFileListItemRef)
-        self.assertIsInstance(kLSSharedFileListItemHidden, unicode)
 
     def testConstants(self):
         self.assertEqual(kLSSharedFileListNoUserInteraction, 1)
@@ -57,12 +67,12 @@ class TestLSSharedFileList (TestCase):
 
         self.assertResultIsCFRetained(LSSharedFileListCopyProperty)
         self.assertResultHasType(LSSharedFileListCopyProperty, b'@')
-        v = LSSharedFileListCopyProperty(lst, u"name")
+        v = LSSharedFileListCopyProperty(lst, b"pyobjc.name".decode('latin1'))
 
-        v = LSSharedFileListSetProperty(lst, u"pyobjc.name", u"value")
+        v = LSSharedFileListSetProperty(lst, b"pyobjc.name".decode('latin1'), b"value".decode('latin1'))
         self.assertIsInstance(v, (int, long))
-        v = LSSharedFileListCopyProperty(lst, u"name")
-        self.assertEqual(v, u"value")
+        v = LSSharedFileListCopyProperty(lst, b"pyobjc.name".decode('latin1'))
+        self.assertEqual(v, b"value".decode('latin1'))
 
         self.assertArgIsOut(LSSharedFileListCopySnapshot, 1)
         v, seed = LSSharedFileListCopySnapshot(lst, None)
@@ -70,7 +80,7 @@ class TestLSSharedFileList (TestCase):
         self.assertIsInstance(seed, (int,long))
 
         self.assertResultIsCFRetained(LSSharedFileListInsertItemURL)
-        item = LSSharedFileListInsertItemURL(lst, kLSSharedFileListItemLast, "PyObjC.Test", None, 
+        item = LSSharedFileListInsertItemURL(lst, kLSSharedFileListItemLast, b"PyObjC.Test".decode('latin1'), None, 
                 CFURLCreateWithString(None, "file:///etc/hosts", None), {}, [])
         self.assertIsInstance(item, LSSharedFileListItemRef)
 
@@ -78,7 +88,8 @@ class TestLSSharedFileList (TestCase):
         self.assertIsInstance(v, (int, long))
 
         v = LSSharedFileListItemCopyIconRef(item)
-        self.assertIsObject(v, None)
+        if v is not None:
+            self.assertIsInstance(v, IconRef)
 
         self.assertResultIsCFRetained(LSSharedFileListItemCopyDisplayName)
         v = LSSharedFileListItemCopyDisplayName(item)
@@ -89,14 +100,16 @@ class TestLSSharedFileList (TestCase):
         self.assertArgIsCFRetained(LSSharedFileListItemResolve, 2)
         v, url, ref = LSSharedFileListItemResolve(item, 0, None, objc.NULL)
         self.assertIsInstance(v, (int, long))
-        self.assertIsInstance(url, CFURLRef)
+        if url is not None:
+            self.assertIsInstance(url, CFURLRef)
 
-        v = LSSharedFileListItemSetProperty(item, u"name", u"pyobjc.test")
+        v = LSSharedFileListItemSetProperty(item, b"pyobjc.name".decode('latin1'), b"pyobjc.test".decode('latin1'))
         self.assertIsInstance(v, (int, long))
 
         self.assertResultIsCFRetained(LSSharedFileListItemCopyProperty)
-        v = LSSharedFileListItemCopyProperty(item, u"name")
-        self.assertEqual(v, "pyobjc.test")
+        v = LSSharedFileListItemCopyProperty(item, b"pyobjc.name".decode('latin1'))
+        if v is not None:
+            self.assertEqual(v, "pyobjc.test")
 
         v = LSSharedFileListItemMove(lst, item, kLSSharedFileListItemBeforeFirst)
         self.assertIsInstance(v, (int, long))
@@ -110,14 +123,7 @@ class TestLSSharedFileList (TestCase):
 
 
 
-
-
-
-
-
-
-
-
+    @expectedFailure
     def testMissing(self):
         # Needs more infrastructure
         self.fail('LSSharedFileListSetAuthorization')
